<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsAboutHomeAgency extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-about-home-agency';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'About Home Agency', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-post-content';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'home-agency-elementor' ];
	}

	public function get_keywords() {
		return [ 'About' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	protected function _register_controls() {

		$this->start_controls_section(
			'section_content_About',
			[
				'label' => esc_html__( 'About Home Agency', 'bdevs-elementor' ),
			]
		);
		$this->add_control(
			'image',
			[
				'label'       => __( 'Background Image 1', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],			
			]
		);
		$this->add_control(
			'icon',
			[
				'label'       => __( 'Icon Image 1', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Icon Image 1', 'bdevs-elementor' ),
				'default'     => __( '+', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	
		$this->add_control(
			'title_image',
			[
				'label'       => __( 'Title Image 1', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Title Image 1', 'bdevs-elementor' ),
				'default'     => __( 'Professionals', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	
		$this->add_control(
			'number_image',
			[
				'label'       => __( 'Number Image 1', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Title Image 1', 'bdevs-elementor' ),
				'default'     => __( '35', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	
		$this->add_control(
			'image2',
			[
				'label'       => __( 'Background Image 2', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],			
			]
		);
		$this->add_control(
			'icon2',
			[
				'label'       => __( 'Icon Image 2', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Icon Image 2', 'bdevs-elementor' ),
				'default'     => __( '+', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	
		$this->add_control(
			'title_image2',
			[
				'label'       => __( 'Title Image 2', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Title Image 2', 'bdevs-elementor' ),
				'default'     => __( 'Professionals', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	
		$this->add_control(
			'number_image2',
			[
				'label'       => __( 'Number Image 2', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Title Image 2', 'bdevs-elementor' ),
				'default'     => __( '14', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);
		$this->add_control(
			'subheading',
			[
				'label'       => __( 'Subheading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Subheading', 'bdevs-elementor' ),
				'default'     => __( 'About Us', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	
		$this->add_control(
			'heading',
			[
				'label'       => __( 'Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),
				'default'     => __( 'We transform brands & businesses from inside out', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title Progress', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Title Progress', 'bdevs-elementor' ),
				'default'     => __( 'MARKETING', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	
		$this->add_control(
			'number_progress',
			[
				'label'       => __( 'Number Progress', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Number Progress', 'bdevs-elementor' ),
				'default'     => __( '94', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	
		$this->add_control(
			'title2',
			[
				'label'       => __( 'Title 2 Progress', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Title 2 Progress', 'bdevs-elementor' ),
				'default'     => __( 'STRATEGY', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	
		$this->add_control(
			'number_progress2',
			[
				'label'       => __( 'Number 2 Progress', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Number 2 Progress', 'bdevs-elementor' ),
				'default'     => __( '90', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	
		$this->add_control(
			'desc',
			[
				'label'       => __( 'Description', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your Description', 'bdevs-elementor' ),
				'default'     => __( 'Lorem ipsum dolor sit amet consectetur adipisicing elit. Nostrum maiores necessitatibus deleniti dolore, enim inventore', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);
		$this->add_control(
			'link_button',
			[
				'label'       => __( 'Link Button', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Link Button', 'bdevs-elementor' ),
				'default'     => __( '#', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	
		$this->add_control(
			'button',
			[
				'label'       => __( ' Button', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Button', 'bdevs-elementor' ),
				'default'     => __( 'Learn More', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	
		
		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);
		$this->add_control(
			'show_image',
			[
				'label'   => esc_html__( 'Show Image', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	
		$this->add_control(
			'show_title_image',
			[
				'label'   => esc_html__( 'Show Title Image', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	
		$this->add_control(
			'show_number_image',
			[
				'label'   => esc_html__( 'Show Number Image', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);
		$this->add_control(
			'show_image2',
			[
				'label'   => esc_html__( 'Show Image 2', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	
		$this->add_control(
			'show_title_image2',
			[
				'label'   => esc_html__( 'Show Title Image 2', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	
		$this->add_control(
			'show_number_image2',
			[
				'label'   => esc_html__( 'Show Number Image 2', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);
		$this->add_control(
			'show_subheading',
			[
				'label'   => esc_html__( 'Show Subheading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	
		$this->add_control(
			'show_heading',
			[
				'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	
		$this->add_control(
			'show_desc',
			[
				'label'   => esc_html__( 'Show Description', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	
		$this->add_control(
			'show_button',
			[
				'label'   => esc_html__( 'Show Button', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	

		$this->end_controls_section();

	}

	public function render() {

		$settings  = $this->get_settings_for_display(); 
		extract($settings); ?>
	<div class="section-box">
		<div class="section bg-lighter border-radius-1">
			<div class="container">
				<div class="row g-5 align-items-center">
					<div class="col-12 col-lg-6">
						<div class="row">
							<div class="col-6 text-end">
								<?php if (( '' !== $settings['image'] ) && ( $settings['show_image'] )) : ?>
								<img class="img-mask-2" src="<?php print esc_url($settings['image']['url']); ?>" alt="">
								<?php endif; ?>
								<div class="d-flex align-items-center justify-content-end mt-3">
									<div class="d-inline-block pe-2">
										<h4 class="line-height-100 fw-normal mb-0"><?php echo wp_kses_post($settings['icon']); ?></h4>
										<?php if (( '' !== $settings['title_image'] ) && ( $settings['show_title_image'] )) : ?>
										<p class="sm-heading"><?php echo wp_kses_post($settings['title_image']); ?></p>
										<?php endif; ?>
									</div>
									<?php if (( '' !== $settings['number_image'] ) && ( $settings['show_number_image'] )) : ?>
									<div class="d-inline-block">
										<h1 class="fw-semi-bold stroke-text display-4 letter-spacing-1"><span class="counter"><?php echo wp_kses_post($settings['number_image']); ?></span></h1>
									</div>
									<?php endif; ?>
								</div>
							</div>
							<div class="col-6">
								<div class="d-flex align-items-center mb-3">
									<?php if (( '' !== $settings['number_image2'] ) && ( $settings['show_number_image2'] )) : ?>
									<div class="d-inline-block">
										<h1 class="fw-semi-bold stroke-text display-4 letter-spacing-1"><span class="counter"><?php echo wp_kses_post($settings['number_image2']); ?></span></h1>
									</div>
									<?php endif; ?>
									<div class="d-inline-block ps-2">
										<h4 class="line-height-100 fw-normal mb-0"><?php echo wp_kses_post($settings['icon2']); ?></h4>
										<?php if (( '' !== $settings['title_image2'] ) && ( $settings['show_title_image2'] )) : ?>
										<p class="sm-heading"><?php echo wp_kses_post($settings['title_image2']); ?></p>
										<?php endif; ?>
									</div>
								</div>
								<?php if (( '' !== $settings['image2'] ) && ( $settings['show_image2'] )) : ?>
								<img class="img-mask-2" src="<?php print esc_url($settings['image2']['url']); ?>" alt="">
								<?php endif; ?>
							</div>
						</div><!-- end row(inner) -->
					</div>
					<div class="col-12 col-lg-6">
						<?php if (( '' !== $settings['subheading'] ) && ( $settings['show_subheading'] )) : ?>
						<h6 class="title-heading mb-3"><?php echo wp_kses_post($settings['subheading']); ?></h6>
						<?php endif; ?>
						<?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )) : ?>
						<h2 class="display-6 fw-normal mb-4"><?php echo wp_kses_post($settings['heading']); ?></h2>
						<?php endif; ?>
						<div class="row g-4 mb-4">
							<div class="col-12 col-md-6">
								<div class="progress-box">
									<h6 class="sm-heading"><?php echo wp_kses_post($settings['title']); ?></h6>
									<div class="animated-progress">
										<div data-progress="<?php echo wp_kses_post($settings['number_progress']); ?>"></div>
									</div>
								</div>
							</div>
							<div class="col-12 col-md-6">
								<div class="progress-box">
									<h6 class="sm-heading"><?php echo wp_kses_post($settings['title2']); ?></h6>
									<div class="animated-progress">
										<div data-progress="<?php echo wp_kses_post($settings['number_progress2']); ?>"></div>
									</div>
								</div>
							</div>
						</div>
						<?php if (( '' !== $settings['desc'] ) && ( $settings['show_desc'] )) : ?>
						<p class="mt-1"><?php echo wp_kses_post($settings['desc']); ?></p>
						<?php endif; ?>
						<?php if (( '' !== $settings['button'] ) && ( $settings['show_button'] )) : ?>
						<a class="button button-lg mt-4" href="<?php echo wp_kses_post($settings['link_button']); ?>"><?php echo wp_kses_post($settings['button']); ?></a>
						<?php endif; ?>
					</div>
				</div><!-- end row -->
			</div><!-- end container -->
		</div>
	</div>
	<?php
	}
}