<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsPortfolioHomeAgency extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-portfolio-home-agency';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Portfolio Home Agency', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-post-content';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'home-agency-elementor' ];
	}

	public function get_keywords() {
		return [ 'Portfolio' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	protected function _register_controls() {

		$this->start_controls_section(
			'section_content_Portfolio',
			[
				'label' => esc_html__( 'Portfolio Home Agency', 'bdevs-elementor' ),
			]
		);
		$this->add_control(
			'subheading',
			[
				'label'       => __( 'Subheading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Subheading', 'bdevs-elementor' ),
				'default'     => __( 'Portfolio', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	
		$this->add_control(
			'heading',
			[
				'label'       => __( 'Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),
				'default'     => __( 'Recent Projects', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	
		$this->add_control(
			'desc',
			[
				'label'       => __( 'Description', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your Description', 'bdevs-elementor' ),
				'default'     => __( 'Lorem ipsum dolor sit, amet consectetur adipisicing elit. Dolorem obcaecati, placeat nemo natus deleniti iusto labore quod quisquam quasi iure dolore architecto maxime beatae', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	
		$this->add_control(
			'number',
			[
				'label'     => esc_html__( 'Post Count', 'bdevs-elementor' ),
				'type'      => Controls_Manager::TEXT,
				'default'   => '4',
			]
		);

		$this->add_control(
			'orderpost',
			[
				'label'     => esc_html__( 'Post Order', 'bdevs-elementor' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => [
					'asc'  => esc_html__( 'ASC', 'bdevs-elementor' ),
					'desc' => esc_html__( 'DESC', 'bdevs-elementor' ),
				],
				'default'   => 'asc',
			]
		);

		$this->add_control(
			'orderby',
			[
				'label'     => esc_html__( 'Order By', 'bdevs-elementor' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => [
					'date'  => esc_html__( 'Date', 'bdevs-elementor' ),
					'title' => esc_html__( 'Title', 'bdevs-elementor' ),
					'rand' => esc_html__( 'Random', 'bdevs-elementor' ),
				],
				'default'   => 'desc',

			]
		);
		
		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);
		
		$this->add_control(
			'show_subheading',
			[
				'label'   => esc_html__( 'Show Subheading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	
		$this->add_control(
			'show_heading',
			[
				'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	
		$this->add_control(
			'show_desc',
			[
				'label'   => esc_html__( 'Show Description', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	

		$this->end_controls_section();

	}

	public function render() {

		$settings  = $this->get_settings_for_display(); 
		extract($settings); ?>
	<div class="section-box">
		<div class="section bg-lighter border-radius-1">
			<div class="container">
				<div class="row">
					<div class="col-12 col-md-10 offset-md-1 col-lg-8 offset-lg-2">
						<?php if (( '' !== $settings['subheading'] ) && ( $settings['show_subheading'] )) : ?>
						<h6 class="title-heading"><?php echo wp_kses_post($settings['subheading']); ?></h6>
						<?php endif; ?>
						<?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )) : ?>
						<h2 class="display-3 fw-medium"><?php echo wp_kses_post($settings['heading']); ?></h2>
						<?php endif; ?>
						<?php if (( '' !== $settings['desc'] ) && ( $settings['show_desc'] )) : ?>
						<p><?php echo wp_kses_post($settings['desc']); ?></p>
						<?php endif; ?>
						<!-- Slider Navigation -->
						<div class="mt-4">
							<div class="button-circle button-circle-lg swiper-portfolio-prev">
								<i class="bi bi-arrow-left"></i>
							</div>
							<div class="button-circle button-circle-lg swiper-portfolio-next">
								<i class="bi bi-arrow-right"></i>
							</div>
						</div>
					</div>
				</div><!-- end row -->
				<div class="swiper portfolio-slider mt-4 mt-lg-5">
					<div class="swiper-wrapper">
						<?php 
	                	$odno_redux_demo = get_option('redux_demo');
	                    $q = new \WP_Query(array(
	                        'post_type'     => 'portfolio',
	                        'posts_per_page'=> $number,
	                        'orderby'       => $orderby,
	                        'order'         => $orderpost,
	                    ));
	                	while($q->have_posts()): $q->the_post();  ?>
						<!-- Slider Item 1 -->
						<div class="swiper-slide">
							<div class="portfolio-box">
								<!-- Image -->
								<?php if ( has_post_thumbnail() ) { ?>
								<div class="portfolio-img">
									<a href="<?php the_permalink(); ?>">
										<img src="<?php echo wp_get_attachment_url(get_post_thumbnail_id());?>" alt="">
									</a>
								</div>
								<?php } ?>
								<div class="pt-4">
									<!-- Categories -->
									<ul class="list-inline-dot sm-heading mb-2">
										<?php 
		                                $categories = get_the_terms(get_the_ID(), 'Type2');
		                                foreach((array)$categories as $cat){
		                                    $cat_name = $cat->name;
		                                    $cat_slug = $cat->slug;
		                                ?>
		                                <li>
		                                    <a class="link-hover" href="<?php echo esc_url( get_category_link( $cat->term_id ) ); ?>"><?php echo esc_attr($cat_name);?></a>
		                                </li>
		                                <?php } ?>
									</ul>
									<!-- Caption -->
									<h2>
										<a class="link-hover-2" href="<?php the_permalink(); ?>">
											<?php the_title(); ?>
										</a>
									</h2>
								</div>
							</div><!-- end portfolio-box -->
						</div>
					<?php endwhile;?>
					</div><!-- end swiper-wrapper -->
				</div><!-- end portfolio-slider -->
			</div><!-- end container -->
		</div>
	</div>
	<?php if (is_admin()) { ?>
<script type="text/javascript">
	var swiper = new Swiper(".portfolio-slider",{
    slidesPerView: 1,
    spaceBetween: 24,
    breakpoints: {
        640: {
            slidesPerView: 1,
            spaceBetween: 24
        },
        768: {
            slidesPerView: 2,
            spaceBetween: 24
        },
        992: {
            slidesPerView: 2,
            spaceBetween: 30
        },
        1200: {
            slidesPerView: 2,
            spaceBetween: 40
        },
        1400: {
            slidesPerView: 2,
            spaceBetween: 50
        }
    },
    navigation: {
        nextEl: ".swiper-portfolio-next",
        prevEl: ".swiper-portfolio-prev"
    }
})
</script>
<?php }  ?>
	<?php
	}
}