<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsTeamHomeAgency extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-team-home-agency';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Team Home Agency', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-post-content';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'home-agency-elementor' ];
	}

	public function get_keywords() {
		return [ 'Team' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	protected function _register_controls() {

		$this->start_controls_section(
			'section_content_Team',
			[
				'label' => esc_html__( 'Team Home Agency', 'bdevs-elementor' ),
			]
		);
		$this->add_control(
			'subheading',
			[
				'label'       => __( 'Subheading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Subheading', 'bdevs-elementor' ),
				'default'     => __( 'Team Members', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	
		$this->add_control(
			'heading',
			[
				'label'       => __( 'Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),
				'default'     => __( 'Meet Our Team', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	
		$this->add_control(
			'desc',
			[
				'label'       => __( 'Description', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your Description', 'bdevs-elementor' ),
				'default'     => __( 'Lorem ipsum dolor sit, amet consectetur adipisicing elit. Dolorem obcaecati, placeat nemo natus deleniti iusto labore quod quisquam quasi iure dolore architecto maxime beatae', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);
		$this->add_control(
			'tabs',
			[
				'label' => esc_html__( 'Team Items', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'tab_title'   => esc_html__( 'Team Items', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'I am item content. Click edit button to change this text.', 'bdevs-elementor' ),
					]
				],
				'fields' => [
					[
						'name'    => 'image',
						'label'   => esc_html__( ' Image ', 'bdevs-elementor' ),
						'type'    => Controls_Manager::MEDIA,
						'dynamic' => [ 'active' => true ],
						'default'     => esc_html__( '' , 'bdevs-elementor' ),
					],
					[
						'name'        => 'facebook',
						'label'       => esc_html__( 'Link Facebook', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'https://www.facebook.com/' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'twitter',
						'label'       => esc_html__( 'Link Twitter', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'https://www.twitter.com/' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'instagram',
						'label'       => esc_html__( 'Link Instagram', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'https://www.instagram.com/' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'subtitle',
						'label'       => esc_html__( 'Subtitle', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Project Manager' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'title',
						'label'       => esc_html__( 'Title', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Laura Arena' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					
				],
			]
		);
		$this->add_control(
			'link_view_all',
			[
				'label'       => __( 'Link View All', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Link View All', 'bdevs-elementor' ),
				'default'     => __( '#', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	
		$this->add_control(
			'view_all',
			[
				'label'       => __( ' View All', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your View All', 'bdevs-elementor' ),
				'default'     => __( 'View All Members', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	
		
		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);
		$this->add_control(
			'show_subheading',
			[
				'label'   => esc_html__( 'Show Subheading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	
		$this->add_control(
			'show_heading',
			[
				'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	
		$this->add_control(
			'show_desc',
			[
				'label'   => esc_html__( 'Show Description', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);
		$this->add_control(
			'show_view_all',
			[
				'label'   => esc_html__( 'Show View All', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	

		$this->end_controls_section();

	}

	public function render() {

		$settings  = $this->get_settings_for_display(); 
		extract($settings); ?>
	<div class="section-lg">
		<div class="container">
			<div class="row">
				<div class="col-12 col-md-10 offset-md-1 col-lg-8 offset-lg-2">
					<?php if (( '' !== $settings['subheading'] ) && ( $settings['show_subheading'] )) : ?>
					<h6 class="title-heading"><?php echo wp_kses_post($settings['subheading']); ?></h6>
					<?php endif; ?>
					<?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )) : ?>
					<h2 class="display-3 fw-medium"><?php echo wp_kses_post($settings['heading']); ?></h2>
					<?php endif; ?>
					<?php if (( '' !== $settings['desc'] ) && ( $settings['show_desc'] )) : ?>
					<p><?php echo wp_kses_post($settings['desc']); ?></p>
					<?php endif; ?>
				</div>
			</div><!-- end row -->
			<div class="row g-4 g-xxl-5 mt-4">
				<!-- Team box 1 -->
				<?php
		        	$i = 0;
		        	foreach ( $settings['tabs'] as $item ) :
		        	$i++;
	        	?>
				<div class="col-12 col-sm-6 col-lg-4" data-cue="fadeIn">
					<div class="team-box">
						<div class="team-img">
							<img src="<?php print esc_url($item['image']['url']); ?>" alt="">
							<div class="team-social">
								<ul class="list-inline">
									<?php if ( '' !== $item['facebook'] ) { ?>
									<li><a class="button-circle button-circle-sm button-style-2" href="<?php print wp_kses_post($item['facebook']); ?>"><i class="bi bi-facebook"></i></a></li>
									<?php } ?>
									<?php if ( '' !== $item['twitter'] ) { ?>
									<li><a class="button-circle button-circle-sm button-style-2" href="<?php print wp_kses_post($item['twitter']); ?>"><i class="bi bi-twitter-x"></i></a></li>
									<?php } ?>
									<?php if ( '' !== $item['instagram'] ) { ?>
									<li><a class="button-circle button-circle-sm button-style-2" href="<?php print wp_kses_post($item['instagram']); ?>"><i class="bi bi-instagram"></i></a></li>
									<?php } ?>
								</ul>
							</div>
						</div>
						<div class="pt-4 text-center">
							<?php if ( '' !== $item['subtitle'] ) { ?>
							<h6 class="sm-heading"><?php print wp_kses_post($item['subtitle']); ?></h6>
							<?php } ?>
							<?php if ( '' !== $item['title'] ) { ?>
							<h3><?php print wp_kses_post($item['title']); ?></h3>
							<?php } ?>
						</div>
					</div>
				</div>
				<!-- Team box 2 -->
				<?php endforeach; ?>
				<!-- end Team box 3 -->
			</div><!-- end row -->
			<?php if (( '' !== $settings['view_all'] ) && ( $settings['show_view_all'] )) : ?>
			<div class="text-center mt-4">
				<a class="button button-lg" href="<?php echo wp_kses_post($settings['link_view_all']); ?>" data-cue="fadeIn"><?php echo wp_kses_post($settings['view_all']); ?></a>
			</div>
			<?php endif; ?>
		</div><!-- end container -->
	</div>
	<?php
	}
}