<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsSliderHomeBusiness extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-slider-home-business';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Slider Home Business', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-post-content';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'home-business-elementor' ];
	}

	public function get_keywords() {
		return [ 'Slider' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	protected function _register_controls() {

		$this->start_controls_section(
			'section_content_Slider',
			[
				'label' => esc_html__( 'Slider Home Business', 'bdevs-elementor' ),
			]
		);
		
		$this->add_control(
			'image',
			[
				'label'       => __( 'Background Image', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],			
			]
		);
		$this->add_control(
			'heading',
			[
				'label'       => __( 'Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),
				'default'     => __( 'We help innovators to successfully bring their business to life', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	
		$this->add_control(
			'subheading',
			[
				'label'       => __( 'Subheading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your Subheading', 'bdevs-elementor' ),
				'default'     => __( 'Lorem ipsum dolor sit amet, consectetur adipisicing elit. Animi architecto beatae doloribus odio nulla vero impedit quam omnis amet est! Ex ratione', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	
		$this->add_control(
			'tabs',
			[
				'label' => esc_html__( 'Slider Avatar Items', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'tab_title'   => esc_html__( 'Slide #1', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'I am item content. Click edit button to change this text.', 'bdevs-elementor' ),
					]
				],
				'fields' => [
					[
						'name'    => 'avatar',
						'label'   => esc_html__( ' Image Avatar', 'bdevs-elementor' ),
						'type'    => Controls_Manager::MEDIA,
						'dynamic' => [ 'active' => true ],
						'default'     => esc_html__( '' , 'bdevs-elementor' ),
					],	
				],
			]
		);
		$this->add_control(
			'desc',
			[
				'label'       => __( ' Description', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Description', 'bdevs-elementor' ),
				'default'     => __( 'We have over 4,000 clients <br class="d-lg-block">around the world', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	
		$this->add_control(
			'link_video',
			[
				'label'       => __( 'Link Video', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Link Video', 'bdevs-elementor' ),
				'default'     => __( 'https://www.youtube.com/watch?v=W-j4QGAgNu8', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	
		
		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);
		
		$this->add_control(
			'show_heading',
			[
				'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	
		$this->add_control(
			'show_subheading',
			[
				'label'   => esc_html__( 'Show Subheading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->end_controls_section();

	}

	public function render() {

		$settings  = $this->get_settings_for_display(); 
		extract($settings); ?>
		<div class="section-box">
		<div class="bg-image border-radius-1" data-bg-src="<?php print esc_url($settings['image']['url']); ?>">
			<div class="section-lg bg-dark-08">
				<div class="container">
					<div class="row g-4 align-items-center">
						<div class="col-12 col-md-10 col-lg-9 col-xl-8 col-xxl-7">
							<?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )) : ?>
							<h1 class="display-5 fw-normal"><?php echo wp_kses_post($settings['heading']); ?></h1>
							<?php endif; ?>
							<?php if (( '' !== $settings['subheading'] ) && ( $settings['show_subheading'] )) : ?>
							<p class="mt-3 mt-lg-4"><?php echo wp_kses_post($settings['subheading']); ?></p>
							<?php endif; ?>
							<div class="d-md-flex align-items-center mt-5">
								<ul class="avatar-group">
									<?php
							        	$i = 0;
							        	foreach ( $settings['tabs'] as $item ) :
							        	$i++;
						        	?>
									<li>
										<img src="<?php print esc_url($item['avatar']['url']); ?>" alt="" data-rjs="2">
									</li>
									<?php endforeach; ?>
								</ul>
								<div class="d-md-inline-block pt-3 pt-md-0 ps-md-4">
									<p><?php echo wp_kses_post($settings['desc']); ?></p>
								</div>
							</div>
						</div>
						<div class="col-12 col-md-2 col-lg-3 col-xl-4 col-xxl-5 text-center">
							<a class="hero-play-btn lightbox-video-link" href="<?php echo wp_kses_post($settings['link_video']); ?>">
								<span><i class="bi bi-play-fill"></i></span>
							</a>
						</div>
					</div><!-- end row -->
				</div><!-- end container -->
			</div>
		</div>
	</div>

<?php if (is_admin()) { ?>
<script type="text/javascript">
	var bgImages = document.querySelectorAll(".bg-image");
bgImages && bgImages.forEach(function(e) {
    var t = e.getAttribute("data-bg-src");
    e.style.backgroundImage = 'url("' + t + '")'
});
var $lightboxVideo = $(".lightbox-video a, .lightbox-video-link");
$lightboxVideo.each(function() {
    $(this).magnificPopup({
        type: "iframe",
        fixedContentPos: !1,
        removalDelay: 200,
        preloader: !1,
        iframe: {
            patterns: {
                youtube: {
                    index: "youtube.com/",
                    id: "v=",
                    src: "//www.youtube.com/embed/%id%?autoplay=1&rel=0"
                },
                vimeo: {
                    index: "vimeo.com/",
                    id: "/",
                    src: "//player.vimeo.com/video/%id%?autoplay=1"
                }
            },
            srcAction: "iframe_src"
        }
    })
})
</script>
<?php }  ?>
	<?php
	}
}