<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsFAQsHomeCorporate extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-faqs-home-corporate';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'FAQs Home Corporate', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-post-content';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'home-corporate-elementor' ];
	}

	public function get_keywords() {
		return [ 'FAQ' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	protected function _register_controls() {

		$this->start_controls_section(
			'section_content_FAQ',
			[
				'label' => esc_html__( 'FAQ Home Corporate', 'bdevs-elementor' ),
			]
		);	
		$this->add_control(
			'tabs',
			[
				'label' => esc_html__( 'Faq Items', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'tab_title'   => esc_html__( 'Slide #1', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'I am item content. Click edit button to change this text.', 'bdevs-elementor' ),
					]
				],
				'fields' => [
					[
						'name'        => 'title',
						'label'       => esc_html__( 'Title', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Where to start?' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'subtitle',
						'label'       => esc_html__( 'Subtitle', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Lorem, ipsum dolor sit amet consectetur adipisicing elit. Quidem officiis corrupti earum dolorem, eveniet obcaecati doloribus, dolores voluptate eum culpa vel? Deserunt nam quod fugit. Ut perspiciatis sequi natus officia.' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					
				],
			]
		);
		$this->add_control(
			'image',
			[
				'label'       => __( 'Background Image', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],			
			]
		);
		$this->add_control(
			'video',
			[
				'label'       => __( 'Link Video', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Link Video', 'bdevs-elementor' ),
				'default'     => __( 'https://www.youtube.com/watch?v=W-j4QGAgNu8', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	
		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);	
		

		$this->end_controls_section();

	}

	public function render() {

		$settings  = $this->get_settings_for_display(); 
		extract($settings); ?>
	<div class="section-lg pt-0">
		<div class="container">
			<div class="row g-4 g-xl-5 align-items-center">
				<div class="col-12 col-lg-6">
					<ul class="accordion">
						<?php
				        	$i = 0;
				        	foreach ( $settings['tabs'] as $item ) :
				        	$i++;
			        	?>
			        	<?php if($i==1){?>
						<li class="active">
							<div class="accordion-title">
								<h4><?php print wp_kses_post($item['title']); ?></h4>
								<div class="title-arrow">
									<i class="fa-solid fa-angle-down"></i>
								</div>
							</div>
							<div class="accordion-content">
								<p><?php print wp_kses_post($item['subtitle']); ?></p>
							</div>
						</li>
						<?php } else {?>
						<li>
							<div class="accordion-title">
								<h4><?php print wp_kses_post($item['title']); ?></h4>
								<div class="title-arrow">
									<i class="fa-solid fa-angle-down"></i>
								</div>
							</div>
							<div class="accordion-content">
								<p><?php print wp_kses_post($item['subtitle']); ?></p>
							</div>
						</li>
						<?php } ?>
						<?php endforeach; ?>
					</ul>
				</div>
				<div class="col-12 col-lg-6" data-cue="fadeIn">
					<div class="lightbox-video">
						<img src="<?php print esc_url($settings['image']['url']); ?>" alt="">
						<?php if ( '' !== $settings['video'] ) { ?>
						<a class="button-circle button-circle-xl button-circle-style-2" href="<?php echo wp_kses_post($settings['video']); ?>">
							<i class="fa-solid fa-play"></i>
						</a>
						<?php } ?>
					</div>
				</div>
			</div><!-- end row -->
		</div><!-- end container -->
	</div>
	<?php
	}
}