<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsAwardsHomePortfolio extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-awards-home-portfolio';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Awards Home Portfolio', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-post-content';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'home-portfolio-elementor' ];
	}

	public function get_keywords() {
		return [ 'Awards' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	protected function _register_controls() {

		$this->start_controls_section(
			'section_content_Awards',
			[
				'label' => esc_html__( 'Awards Home Portfolio', 'bdevs-elementor' ),
			]
		);
		$this->add_control(
			'tabs2',
			[
				'label' => esc_html__( 'Services Progress Items', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'tab_title'   => esc_html__( 'Slide #1', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'I am item content. Click edit button to change this text.', 'bdevs-elementor' ),
					]
				],
				'fields' => [
					[
						'name'        => 'title_progress',
						'label'       => esc_html__( 'Title Progress', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Advertising' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'number_progress',
						'label'       => esc_html__( 'Number Progress', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( '94' , 'bdevs-elementor' ),
						'label_block' => true,
					],	
				],
			]
		);
		$this->add_control(
			'tabs',
			[
				'label' => esc_html__( 'Services Avatar Items', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'tab_title'   => esc_html__( 'Slide #1', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'I am item content. Click edit button to change this text.', 'bdevs-elementor' ),
					]
				],
				'fields' => [
					[
						'name'        => 'title',
						'label'       => esc_html__( 'Title', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Most Innovative' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'link_title',
						'label'       => esc_html__( 'Link Title', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( '#' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'number',
						'label'       => esc_html__( 'Number', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( '2022' , 'bdevs-elementor' ),
						'label_block' => true,
					],	
					
					[
						'name'        => 'subtitle',
						'label'       => esc_html__( 'Subtitle', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Lorem ipsum dolor sit amet consectetur adipisicing elit. Nobis fugiat libero neque obcaecati molestias' , 'bdevs-elementor' ),
						'label_block' => true,
					],
				],
			]
		);
		
		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);

		$this->end_controls_section();

	}

	public function render() {

		$settings  = $this->get_settings_for_display(); 
		extract($settings); ?>
	<div class="section-lg pt-0">
		<div class="container">
			<div class="row g-4 g-xxl-5 align-items-center">
				<div class="col-12 col-lg-4">
					<div class="row g-4">
						<?php
				        	$i = 0;
				        	foreach ( $settings['tabs2'] as $item2 ) :
				        	$i++;
			        	?>
						<div class="col-12">
							<div class="progress-box">
								<h6 class="sm-heading"><?php print wp_kses_post($item2['title_progress']); ?></h6>
								<div class="animated-progress">
									<div data-progress="<?php print wp_kses_post($item2['number_progress']); ?>"></div>
								</div>
							</div>
						</div>
						<?php endforeach; ?>
					</div>
				</div>
				<?php
		        	$i = 0;
		        	foreach ( $settings['tabs'] as $item ) :
		        	$i++;
	        	?>
				<div class="col-12 col-lg-4" data-cue="fadeIn">
					<div class="fancy-box">
						<h3><a href ="<?php print wp_kses_post($item['link_title']); ?>"><?php print wp_kses_post($item['title']); ?></a></h3>
						<h6 class="sm-heading"><?php print wp_kses_post($item['number']); ?></h6>
						<?php if ( '' !== $item['subtitle'] ) { ?>
						<p><?php print wp_kses_post($item['subtitle']); ?></p>
						<?php } ?>
					</div>
				</div>
				<?php endforeach; ?>
			</div><!-- end row -->
		</div><!-- end container -->
	</div>
	<?php
	}
}