<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsMediaHomeStartup extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-media-home-startup';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Media Home Startup', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-post-content';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'home-startup-elementor' ];
	}

	public function get_keywords() {
		return [ 'Media' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	protected function _register_controls() {

		$this->start_controls_section(
			'section_content_Media',
			[
				'label' => esc_html__( 'Media Home Startup', 'bdevs-elementor' ),
			]
		);
			
		$this->add_control(
			'image',
			[
				'label'       => __( ' Image Left', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],			
			]
		);
		$this->add_control(
			'image2',
			[
				'label'       => __( ' Image Center', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],			
			]
		);
		$this->add_control(
			'video',
			[
				'label'       => __( 'Link Video ', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Link Video ', 'bdevs-elementor' ),
				'default'     => __( 'https://www.youtube.com/watch?v=W-j4QGAgNu8', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	
		$this->add_control(
			'image3',
			[
				'label'       => __( ' Image Right', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],			
			]
		);
		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);
		
		$this->add_control(
			'show_image',
			[
				'label'   => esc_html__( 'Show Image Left', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	
		$this->add_control(
			'show_image2',
			[
				'label'   => esc_html__( 'Show Image Center', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);
		$this->add_control(
			'show_image3',
			[
				'label'   => esc_html__( 'Show Image Right', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->end_controls_section();

	}

	public function render() {

		$settings  = $this->get_settings_for_display(); 
		extract($settings); ?>
	<div class="section pt-0">
        <div class="container">
            <div class="row g-4 g-xxl-5 align-items-center">
            	<?php if (( '' !== $settings['image'] ) && ( $settings['show_image'] )) : ?>
                <div class="col-12 col-md-4">
                    <img class="img-mask-1" src="<?php print esc_url($settings['image']['url']); ?>" alt="">
                </div>
                <?php endif; ?>
                <?php if (( '' !== $settings['image2'] ) && ( $settings['show_image2'] )) : ?>
                <div class="col-12 col-md-4">
                    <div class="lightbox-video">
                        <img src="<?php print esc_url($settings['image2']['url']); ?>" alt="">
                        <a class="button-circle button-circle-xl" href="<?php echo wp_kses_post($settings['video']); ?>">
                            <i class="fa-solid fa-play"></i>
                        </a>
                    </div>
                </div>
                <?php endif; ?>
                <?php if (( '' !== $settings['image3'] ) && ( $settings['show_image3'] )) : ?>
                <div class="col-12 col-md-4">
                    <img class="img-mask-2" src="<?php print esc_url($settings['image3']['url']); ?>" alt="">
                </div>
                <?php endif; ?>
            </div><!-- end row -->
        </div><!-- end container -->
    </div>
	<?php
	}
}