<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsContactPage extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-contact-page';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Contact Pages', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-post-content';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'other-pages-elementor' ];
	}

	public function get_keywords() {
		return [ 'Contact' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	protected function _register_controls() {

		$this->start_controls_section(
			'section_content_Contact',
			[
				'label' => esc_html__( 'Contact About Pages', 'bdevs-elementor' ),
			]
		);
		$this->add_control(
			'subheading',
			[
				'label'       => __( 'Subheading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Subheading', 'bdevs-elementor' ),
				'default'     => __( 'Contact Us', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	
		$this->add_control(
			'heading',
			[
				'label'       => __( 'Heading ', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your heading ', 'bdevs-elementor' ),
				'default'     => __( 'Get In Touch', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	
		$this->add_control(
			'desc',
			[
				'label'       => __( 'Description ', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your Description ', 'bdevs-elementor' ),
				'default'     => __( 'Lorem ipsum dolor sit, amet consectetur adipisicing elit. Dolorem obcaecati, placeat nemo natus deleniti iusto labore quod quisquam quasi iure dolore architecto maxime beatae', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	
		$this->add_control(
			'facebook',
			[
				'label'       => __( 'Link Facebook ', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Facebook ', 'bdevs-elementor' ),
				'default'     => __( 'https://facebook.com/', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	
		$this->add_control(
			'twitter',
			[
				'label'       => __( 'Link Twitter ', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Twitter ', 'bdevs-elementor' ),
				'default'     => __( 'https://twitter.com/', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	
		$this->add_control(
			'instagram',
			[
				'label'       => __( 'Link Instagram ', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Instagram ', 'bdevs-elementor' ),
				'default'     => __( 'https://instagram.com/', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	
		$this->add_control(
			'contact_form',
			[
				'label'       => __( 'Contact Form ', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Contact Form ', 'bdevs-elementor' ),
				'default'     => __( '[contact-form-7 id="180" title="Contact Form"]', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	
		$this->add_control(
			'title_phone',
			[
				'label'       => __( 'Title Phone', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Title Phone ', 'bdevs-elementor' ),
				'default'     => __( 'SUPPORT:', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);
		$this->add_control(
			'phone',
			[
				'label'       => __( 'Phone', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Phone ', 'bdevs-elementor' ),
				'default'     => __( '+123 456 7890', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);
		$this->add_control(
			'title_address',
			[
				'label'       => __( 'Title Address', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Title Address ', 'bdevs-elementor' ),
				'default'     => __( 'HEADQUARTERS:', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);
		$this->add_control(
			'address',
			[
				'label'       => __( 'Address', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Address ', 'bdevs-elementor' ),
				'default'     => __( '551 Swanston Street, Melbourne Victoria 3053 Australia', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);
		$this->add_control(
			'map',
			[
				'label'       => __( 'Link Map', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your Address ', 'bdevs-elementor' ),
				'default'     => __( 'https://www.google.com/maps/embed?pb=!1m18!1m12!1m3!1d96873.5592703942!2d-74.02739776946056!3d40.64534496902129!2m3!1f0!2f0!3f0!3m2!1i1024!2i768!4f13.1!3m3!1m2!1s0x89c24416947c2109%3A0x82765c7404007886!2zQnJvb2tseW4sIFRp4buDdSBiYW5nIE5ldyBZb3JrLCBIb2EgS-G7sw!5e0!3m2!1svi!2s!4v1703557423006!5m2!1svi!2s', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);
		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);
		
		$this->add_control(
			'show_heading',
			[
				'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	
		$this->add_control(
			'show_subheading',
			[
				'label'   => esc_html__( 'Show Subheading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);
		$this->add_control(
			'show_desc',
			[
				'label'   => esc_html__( 'Show Description', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);
		$this->add_control(
			'show_desc2',
			[
				'label'   => esc_html__( 'Show Description 2', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->end_controls_section();

	}

	public function render() {

		$settings  = $this->get_settings_for_display(); 
		extract($settings); ?>
	<div class="section-lg">
        <div class="container">
            <div class="row">
				<div class="col-12 col-md-10 offset-md-1 col-lg-8 offset-lg-2">
					<?php if (( '' !== $settings['subheading'] ) && ( $settings['show_subheading'] )) : ?>
					<h6 class="title-heading"><?php echo wp_kses_post($settings['subheading']); ?></h6>
					<?php endif; ?>
					<?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )) : ?>
					<h2 class="display-3 fw-medium"><?php echo wp_kses_post($settings['heading']); ?></h2>
					<?php endif; ?>
					<?php if (( '' !== $settings['desc'] ) && ( $settings['show_desc'] )) : ?>
					<p><?php echo wp_kses_post($settings['desc']); ?></p>
					<?php endif; ?>
                    <ul class="list-inline mt-4">
                    	<?php if ( '' !== $settings['facebook'] ) { ?>
                        <li>
                            <a class="button-circle" href="<?php print wp_kses_post($settings['facebook']); ?>"><i class="bi bi-facebook"></i></a>
                        </li>
                        <?php } ?>
                        <?php if ( '' !== $settings['twitter'] ) { ?>
                        <li>
                            <a class="button-circle" href="<?php print wp_kses_post($settings['twitter']); ?>"><i class="bi bi-twitter-x"></i></a>
                        </li>
                        <?php } ?>
                        <?php if ( '' !== $settings['instagram'] ) { ?>
                        <li>
                            <a class="button-circle" href="<?php print wp_kses_post($settings['instagram']); ?>"><i class="bi bi-instagram"></i></a>
                        </li>
                        <?php } ?>
                    </ul>
                </div>
			</div><!-- end row -->
            <div class="row g-5 mt-2">
                <div class="col-12 col-xl-8">
                    <!-- Contact Form -->
                    <div class="contact-form">
                        <?php echo do_shortcode($settings['contact_form']); ?>
                    </div><!-- end contact-form -->
                </div>
                <div class="col-12 col-xl-4">
                	<?php if ( '' !== $settings['title_phone'] ) { ?>
                    <h6 class="sm-heading"><?php echo wp_kses_post($settings['title_phone']); ?></h6>
                    <?php } ?>
                    <?php if ( '' !== $settings['phone'] ) { ?>
                    <h3><?php echo wp_kses_post($settings['phone']); ?></h3>
                    <?php } ?>
                    <div class="mt-4 mt-xl-5">
                    	<?php if ( '' !== $settings['title_address'] ) { ?>
                        <h6 class="sm-heading"><?php echo wp_kses_post($settings['title_address']); ?></h6>
                        <?php } ?>
                        <?php if ( '' !== $settings['address'] ) { ?>
                        <h3><?php echo wp_kses_post($settings['address']); ?></h3>
                        <?php } ?>
                    </div>
                </div>
            </div><!-- end row -->
            <?php if ( '' !== $settings['map'] ) { ?>
            <div class="gmap gmap-md border-radius-1 mt-5"><iframe src="<?php echo wp_kses_post($settings['map']); ?>" width="100%" height="450" style="border:0;" allowfullscreen="" loading="lazy" referrerpolicy="no-referrer-when-downgrade"></iframe></div>
            <?php } ?>
        </div><!-- end container-->
    </div>

	<?php
	}
}