<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsSliderAboutPages extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-slider-about';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Slider About Pages', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-post-content';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'other-pages-elementor' ];
	}

	public function get_keywords() {
		return [ 'Slider' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	protected function _register_controls() {

		$this->start_controls_section(
			'section_content_Slider',
			[
				'label' => esc_html__( 'Slider About Pages', 'bdevs-elementor' ),
			]
		);
			
		$this->add_control(
			'heading',
			[
				'label'       => __( 'Heading ', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your heading ', 'bdevs-elementor' ),
				'default'     => __( 'Creating the Best Solutions for your Business', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	
		$this->add_control(
			'desc',
			[
				'label'       => __( 'Description ', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your Description ', 'bdevs-elementor' ),
				'default'     => __( '', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	
		$this->add_control(
			'desc2',
			[
				'label'       => __( 'Description 2', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your Description 2', 'bdevs-elementor' ),
				'default'     => __( '', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	
		$this->add_control(
			'tabs',
			[
				'label' => esc_html__( 'Slider Avatar Items', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'tab_title'   => esc_html__( 'Slide #1', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'I am item content. Click edit button to change this text.', 'bdevs-elementor' ),
					]
				],
				'fields' => [
					[
						'name'    => 'image',
						'label'   => esc_html__( ' Image ', 'bdevs-elementor' ),
						'type'    => Controls_Manager::MEDIA,
						'dynamic' => [ 'active' => true ],
						'default'     => esc_html__( '' , 'bdevs-elementor' ),
					],	
				],
			]
		);
		$this->add_control(
			'subheading',
			[
				'label'       => __( 'Subheading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your Subheading', 'bdevs-elementor' ),
				'default'     => __( 'Lorem, ipsum dolor sit amet consectetur adipisicing elit. In minus quasi eos doloribus soluta animi incidunt molestiae inventore minima mollitia vel quos aut, obcaecati officiis error. Fugiat aliquam cupiditate enim.', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	
		$this->add_control(
			'image',
			[
				'label'       => __( 'Background Image', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],			
			]
		);
		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);
		
		$this->add_control(
			'show_heading',
			[
				'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	
		$this->add_control(
			'show_subheading',
			[
				'label'   => esc_html__( 'Show Subheading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);
		$this->add_control(
			'show_desc',
			[
				'label'   => esc_html__( 'Show Description', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);
		$this->add_control(
			'show_desc2',
			[
				'label'   => esc_html__( 'Show Description 2', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->end_controls_section();

	}

	public function render() {

		$settings  = $this->get_settings_for_display(); 
		extract($settings); ?>
		<div class="section-lg">
		<div class="container">
			<div class="row g-xxl-5 align-items-center">
				<div class="col-12 col-lg-10 col-xl-8">
					<?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )) : ?>
					<h1 class="display-3 fw-normal"><?php echo wp_kses_post($settings['heading']); ?></h1>
					<?php endif; ?>
					<div class="row g-2 g-md-3 mt-3">
						<?php if (( '' !== $settings['desc'] ) && ( $settings['show_desc'] )) : ?>
						<div class="col-12 col-md-6">
							<ul class="list-unstyled">
								<?php echo wp_kses_post($settings['desc']); ?>
							</ul>
						</div>
						<?php endif; ?>
						<?php if (( '' !== $settings['desc2'] ) && ( $settings['show_desc2'] )) : ?>
						<div class="col-12 col-md-6">
							<ul class="list-unstyled">
								<?php echo wp_kses_post($settings['desc2']); ?>
							</ul>
						</div>
						<?php endif; ?>
					</div><!-- end row(inner) -->
					<div class="d-md-flex align-items-center mt-5">
						<ul class="avatar-group">
							<?php
					        	$i = 0;
					        	foreach ( $settings['tabs'] as $item ) :
					        	$i++;
				        	?>
							<li>
								<img src="<?php print esc_url($item['image']['url']); ?>" alt="" data-rjs="2">
							</li>
							<?php endforeach; ?>
						</ul>
						<?php if (( '' !== $settings['subheading'] ) && ( $settings['show_subheading'] )) : ?>
						<div class="d-md-inline-block pt-3 pt-md-0 ps-md-4">
							<p><?php echo wp_kses_post($settings['subheading']); ?></p>
						</div>
						<?php endif; ?>
					</div>
				</div>
				<div class="col-12 col-xxl-4 text-xxl-end d-none d-xxl-block">
					<img class="img-mask-1" src="<?php print esc_url($settings['image']['url']); ?>" alt="">
				</div>
			</div><!-- end row -->
		</div><!-- end container -->
	</div>


	<?php
	}
}